from setuptools import setup

setup(
    name="shant1stpackage",          # Package name
    version="0.1",             # Version
    packages=["shant1stmodule"],     # Python module directories to include
)
